qualpal.Palette
===============

.. currentmodule:: qualpal

.. autoclass:: Palette
   :members:
   :show-inheritance:
   :inherited-members:
   :special-members: __call__, __add__, __mul__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Palette.distance_matrix
      ~Palette.hex
      ~Palette.min_distance
      ~Palette.min_distances
      ~Palette.rgb
      ~Palette.show
      ~Palette.to_css
      ~Palette.to_json
   
   

   
   
   